# MultiCons

This python package provides an implementation of the MultiCons (Multiple Consensus)
algorithm.

MultiCons is a consensus clustering method that uses the frequent closed itemset mining
technique to find similarities in the base clustering solutions.

The implementation aims to follow the original description of the MultiCons method from
the references below.

# Documentation

To get started, check out some examples or look up the reference API, please visit our
[documentation page](https://sergiosim.github.io/multicons/).

## References

Atheer A. "A closed patterns-based approach to the consensus clustering problem".
Other [cs.OH]. Université Côte d’Azur, 2016. English. <NNT : 2016AZUR4111>. <tel-01478626>
Retrieved from [tel.archives-ouvertes.fr](https://tel.archives-ouvertes.fr/tel-01478626)

Atheer A., Pasquier N., Precioso F. "Using Closed Patterns to Solve the Consensus Clustering Problem".
International Journal of Software Engineering and Knowledge Engineering 2016 26:09n10, 1379-1397
